@@ -1,6 +1,6 @@
 /*	This file is part of the auxiliaries library.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: ForEachFile.c,v 1.17 2013-05-12 09:58:34 Gebruiker Exp $
+	$Id: ForEachFile.c,v 1.19 2014-07-28 09:18:11 Gebruiker Exp $
 */
 
 #include	<string.h>
@@ -24,108 +24,40 @@
 
 /* Library module source code */
 
-struct ino_link {			/* to detect loop in file system */
+							/* LOOP DETECTION */
+struct ino_link {
 	struct ino_link *next;
 	long il_ino;
 	long il_device;
 };
 
-static void do_FEF(
-	Fchar *fn,
-	void (*proc)(const Fchar *, const char *, const struct stat *),
-	int dev,
-	struct ino_link *inop,
-	Fchar separator,
-	int max_depth
-);
-
-static Fchar
-get_separator(const Fchar *fn) {
-#ifndef	MSDOS
-	(void)(fn);			/* use fn */
-	return '/';
+static int
+in_ino_list(const struct ino_link *inop, const struct stat *st) {
+	while (inop) {
+#ifdef	UNIX
+		if (	inop->il_ino == st->st_ino
+		&&	inop->il_device == st->st_dev
+		)	return 1;
 #else
-	/* under MSDOS, conform to user's use, or use '\' */
-	Fchar sep = 0;
-
-	while (*fn) {
-		if (*fn == '/' || *fn == '\\') {
-			if (sep == 0) {
-				sep = *fn;
-			}
-			else
-			if (sep != *fn) return 0;	/* bad mixed use */
-		}
-		fn++;
-	}
-	return (sep ? sep : '\\');
+#ifdef	lint
+		st = st;
 #endif
+#endif
+		inop = inop->next;
+	}
+	return 0;
 }
 
 static void
-clean_name(Fchar *fn, Fchar sep) {
-	Fchar *f1 = fn;
-	Fchar *f2 = fn;
-
-	/* remove multiple separators */
-	while (*f1) {
-		if (*f1 == sep && *(f1+1) == sep) {
-			f1++;
-		} else {
-			*f2++ = *f1++;
-		}
-	}
-	*f2 = '\0';
-
-	/* remove a trailing separator */
-	if (f2-1 > fn && *(f2-1) == sep) {
-		*(f2-1) = '\0';
-	}
-}
-
-static void
-do_ForEachFile(
-	const Fchar *fn,
-	void (*proc)(const Fchar *, const char *, const struct stat *),
-	int max_depth
+link_ino_list(
+    struct ino_link *inop, struct ino_link *ninop, const struct stat *st
 ) {
-	Fchar fname[MAX_FILE_NAME_LENGTH];
-	Fchar separator;
-
-	Fnamecpy(fname, (!fn || !*fn) ? str2Fname(".") : fn);
-	separator = get_separator(fname);
-	if (!separator) {
-		(*proc)(fname, "both / and \\ used as separators", 0);
-		return;
-	}
-
-	clean_name(fname, separator);
-	do_FEF(fname, proc, -1, (struct ino_link *)0, separator, max_depth);
-}
-
-static int in_ino_list(const struct ino_link *inop, const struct stat *st);
-static void link_ino_list(
-	struct ino_link *inop,
-	struct ino_link *ninop,
-	const struct stat *st
-);
-
-void
-ForEachFile(
-	const Fchar *fn,
-	void (*proc)(const Fchar *, const char *, const struct stat *)
-) {
-	do_ForEachFile(fn, proc, -1);	/* infinitely deep */
-}
-
-void
-ForEachLocalFile(
-	const Fchar *fn,
-	void (*proc)(const Fchar *, const char *, const struct stat *)
-) {
-	do_ForEachFile(fn, proc, 1);	/* one level deep */
+	ninop->next = inop;
+	ninop->il_ino = st->st_ino;
+	ninop->il_device = st->st_dev;
 }
 
+							/* TREE SCANNING */
 #ifdef	S_IFLNK				/* system with symbolic links */
 #define	LSTAT	lstat
 #else	/* S_IFLNK */
@@ -220,30 +152,86 @@ do_FEF(
 	}
 }
 
-static int
-in_ino_list(const struct ino_link *inop, const struct stat *st) {
-	while (inop) {
-#ifdef	UNIX
-		if (	inop->il_ino == st->st_ino
-		&&	inop->il_device == st->st_dev
-		)	return 1;
+static Fchar
+get_separator(const Fchar *fn) {
+#ifndef	MSDOS
+	(void)(fn);			/* use fn */
+	return '/';
 #else
-#ifdef	lint
-		st = st;
-#endif
-#endif
-		inop = inop->next;
+	/* under MSDOS, conform to user's use, or use '\' */
+	Fchar sep = 0;
+
+	while (*fn) {
+		if (*fn == '/' || *fn == '\\') {
+			if (sep == 0) {
+				sep = *fn;
+			}
+			else
+			if (sep != *fn) return 0;	/* bad mixed use */
+		}
+		fn++;
 	}
-	return 0;
+	return (sep ? sep : '\\');
+#endif
 }
 
 static void
-link_ino_list(
-    struct ino_link *inop, struct ino_link *ninop, const struct stat *st
+clean_name(Fchar *fn, Fchar sep) {
+	Fchar *f1 = fn;
+	Fchar *f2 = fn;
+
+	/* remove multiple separators */
+	while (*f1) {
+		if (*f1 == sep && *(f1+1) == sep) {
+			f1++;
+		} else {
+			*f2++ = *f1++;
+		}
+	}
+	*f2 = '\0';
+
+	/* remove a trailing separator */
+	if (f2-1 > fn && *(f2-1) == sep) {
+		*(f2-1) = '\0';
+	}
+}
+
+static void
+do_ForEachFile(
+	const Fchar *fn,
+	void (*proc)(const Fchar *, const char *, const struct stat *),
+	int max_depth
 ) {
-	ninop->next = inop;
-	ninop->il_ino = st->st_ino;
-	ninop->il_device = st->st_dev;
+	Fchar fname[MAX_FILE_NAME_LENGTH];
+	Fchar separator;
+
+	Fnamecpy(fname, (!fn || !*fn) ? str2Fname(".") : fn);
+	separator = get_separator(fname);
+	if (!separator) {
+		(*proc)(fname, "both / and \\ used as separators", 0);
+		return;
+	}
+
+	clean_name(fname, separator);
+	do_FEF(fname, proc, -1, (struct ino_link *)0, separator, max_depth);
+}
+
+							/* THE ENTRIES */
+void
+ForEachFile(
+	const Fchar *fn,
+	void (*proc)(const Fchar *, const char *, const struct stat *)
+) {
+	do_ForEachFile(fn, proc, -1);	/* infinitely deep */
+}
+
+void
+ForEachLocalFile(
+	const Fchar *fn,
+	void (*proc)(const Fchar *, const char *, const struct stat *),
+	int depth
+) {
+	do_ForEachFile(fn, proc, depth);
 }
 
 /* End library module source code */
@@ -253,7 +241,7 @@ link_ino_list(
 static void
 satisfy_lint(void *x) {
 	ForEachFile(0, 0);
-	ForEachLocalFile(0, 0);
+	ForEachLocalFile(0, 0, 0);
 	satisfy_lint(x);
 }
 #endif	/* lint */
