@@ -1,6 +1,6 @@
 /*	This file is part of the auxiliaries library.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: ForEachFile.h,v 1.8 2013-05-12 09:58:34 Gebruiker Exp $
+	$Id: ForEachFile.h,v 1.9 2014-07-28 09:18:11 Gebruiker Exp $
 */
 
 #ifndef	_FOREACHFILE_H_
@@ -35,7 +35,8 @@ extern void ForEachFile(
 );
 extern void ForEachLocalFile(
 	const Fchar *fn,
-	void (*proc)(const Fchar *fn, const char *msg, const struct stat *fs)
+	void (*proc)(const Fchar *fn, const char *msg, const struct stat *fs),
+	int depth
 );
 
 #endif	/* _FOREACHFILE_H_ */
