@@ -1,10 +1,10 @@
 /*	This file is part of the module ANY_INT.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: any_int.h,v 1.1 2014-01-27 11:22:40 Gebruiker Exp $
+	$Id: any_int.h,v 1.3 2014-09-25 06:58:25 Gebruiker Exp $
 */
 
-#ifndef	_ANY_UINT_H_
-#define _ANY_UINT_H_
+#ifndef	_ANY_INT_H_
+#define _ANY_INT_H_
 
 /*	Printing size_t and very long ints.
 
@@ -15,9 +15,10 @@
    but this is not portable since not all compilers know it.
 
    These problems are solved by introducing the type vlong_[u]int (see below),
-   defined as the largest [unsigned] int type on the system, and routines to
-   convert these to string. The resulting string is transient, but up to
-   N_INDEPENDENT_CALLS calls can be used simultaneously.
+   defined as the largest [unsigned] machine int type on the system,
+   and routines to convert these to string.
+   The resulting string is transient, but up to N_INDEPENDENT_CALLS calls
+   can be used simultaneously.
 
    Since the value is passed to the conversion routines as a typed parameter
    the C compiler does the conversion (actually widening) for you.
@@ -31,4 +32,4 @@ typedef unsigned long long int vlong_uint;	/* largest uint in the system */
 extern const char *any_int2string(vlong_int val, int size);
 extern const char *any_uint2string(vlong_uint val, int size);
 
-#endif	/* _ANY_UINT_H_ */
+#endif	/* _ANY_INT_H_ */
