@@ -1,6 +1,6 @@
 /*	This file is part of the debugging module DEBUG.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: debug.c,v 1.6 2013-05-12 09:58:34 Gebruiker Exp $
+	$Id: debug.c,v 1.7 2014-09-25 06:58:25 Gebruiker Exp $
 */
 
 #include	<stdlib.h>
@@ -45,7 +45,7 @@ wr_str(const char *s) {
 }
 
 void
-wr_info(const char *s, int b, int v) {
+wr_info(const char *s, int v) {
 	/* print the string */
 	if (s) {
 		int cnt = 0;
@@ -84,29 +84,12 @@ wr_info(const char *s, int b, int v) {
 	}
 
 	/* print the value */
-	if (b != 0) {
-		wr_char(' ');
-		if (v < 0) {
-			wr_char('-');
-			v = -v;
-		}
-		switch (b) {
-		case 8:
-			wr_char('0');
-			wr_num(b, v);
-			break;
-		default:
-			wr_num(10, v);
-			break;
-		case 16:
-			wr_char('#');
-			wr_num(b, v);
-			break;
-		case 128:
-			wr_char(v);
-			break;
-		}
+	wr_char(' ');
+	if (v < 0) {
+		wr_char('-');
+		v = -v;
 	}
+	wr_num(10, v);
 
 	wr_char('\n');
 }
@@ -115,7 +98,7 @@ wr_info(const char *s, int b, int v) {
 
 /*ARGSUSED*/
 void
-wr_info(const char *s, int b, int v) {
+wr_info(const char *s, int v) {
 }
 
 #endif	/* DEBUG */
@@ -126,7 +109,7 @@ wr_info(const char *s, int b, int v) {
 #ifdef	lint
 static void
 satisfy_lint(void *x) {
-	wr_info((char *)x, 0, 0);
+	wr_info((char *)x, 0);
 	satisfy_lint(x);
 }
 #endif	/* lint */
