@@ -1,6 +1,6 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: hash.c,v 2.23 2014-01-27 20:50:50 Gebruiker Exp $
+	$Id: hash.c,v 2.27 2015-01-17 10:20:40 dick Exp $
 */
 
 /*	Text is compared by comparing every substring to all substrings
@@ -9,11 +9,11 @@
 	which gives us the possibility to speed up this process by using
 	a hash table.
 
-	For every position in the text, we construct an index which gives
-	the next position in the text at which a run of Min_Run_Size tokens
-	starts that has the same hash code, as calculated by hash1().  If
-	there is no such run, the index is 0.  These forward references are
-	kept in the array forward_reference[].
+	For every position p in the text, we construct an index
+	forward_reference[p] which gives the next position in the text
+	at which a run of Min_Run_Size tokens starts that has the same
+	hash code, as calculated by hash1().  If there is no such run,
+	the index is 0.
 
 	To construct this array, we use a hash table last_index[] whose size
 	is a prime and which is about 8 times smaller than the text array.
@@ -29,6 +29,14 @@
 	the same value under a second hash function, hash2().  For the UNIX
 	manuals this reduced the number of matches from 91.9% to 1.9% (of
 	which 0.06% was genuine).
+
+	The forward references can be checked with db_forward_reference_check(),
+	which also collects Statistics. These can be compared to the perfect
+	forward references created by db_make_forward_references_perfect().
+	For the LaTeX sourcces of our book Modern Compiler Desgin, 2nd Ed. the
+	second hashing reduced the total forward chain length from 103555 to
+	388, whereas the total length for perfect forward references would be
+	345, all 3 numbers as determined by db_forward_reference_check().
 */
 
 #include	<stdio.h>
@@ -53,28 +61,26 @@ static size_t *forward_reference;		/* to be filled by Malloc() */
 static size_t n_forward_references;
 
 static void make_forward_references_hash1(void);
-static void make_forward_references_hash2(void);
+static void clean_forward_references_hash2(void);
 
 #ifdef	DB_FORW_REF
-static void db_forward_references(const char *);
-static void make_forward_references_hash3(void);
-#endif
+static void db_forward_reference_check(const char *);
+static void db_make_forward_references_perfect(void);
+#endif	/* DB_FORW_REF */
 
 void
 Make_Forward_References(void) {
 	/*	Constructs the forward references table.
 	*/
 
-	n_forward_references = Text_Length();
+	n_forward_references = Token_Array_Length();
 	forward_reference =
-		(size_t *)Calloc(
-			n_forward_references, sizeof (size_t)
-		);
+		(size_t *)Calloc(n_forward_references, sizeof (size_t));
 	make_forward_references_hash1();
-	make_forward_references_hash2();
+	clean_forward_references_hash2();
 #ifdef	DB_FORW_REF
-	make_forward_references_hash3();
-#endif
+	db_make_forward_references_perfect();
+#endif	/* DB_FORW_REF */
 }
 
 size_t
@@ -94,27 +100,16 @@ Free_Forward_References(void) {
 /*
 	We want a hash function whose time cost does not depend on
 	Min_Run_Size, which is a problem since the size of the object
-	we derive the hash value from IS equal to Min_Run_Size!
+	we derive the hash value from *is* equal to Min_Run_Size!
 	Therefore we base the hash function on a sample of at most
 	N_SAMPLES tokens from the input string; this works just
 	as well in practice.
 */
 
 #define	N_SAMPLES	24
-#define	OPERATION	^
-
-/*	An alternative algorithm; does not seem to make any difference.
-#define	N_SAMPLES	23
-#define	OPERATION	+
-*/
-
-/*	Another algorithm; not yet tested
-#define	N_SAMPLES	24
-#define	OPERATION	+ 613 *
-*/
 
 static size_t *last_index;
-static size_t hash_table_size;
+static size_t last_index_table_size;
 /* positions where the N_SAMPLES samples can be found: */
 static size_t sample_pos[N_SAMPLES];
 
@@ -171,26 +166,32 @@ init_hash_table(void) {
 
 	/* find the ideal hash table size */
 	n = 0;
-	while (prime[n] < Text_Length()) {
+	while (prime[n] < Token_Array_Length()) {
 		n++;
 		/* this will always terminate, if prime[] is large enough */
 	}
 
 	/* see if we can allocate that much space, and if not, step down */
 	last_index = 0;
-	while (!last_index && n >= 0) {
-		hash_table_size = prime[n];
+	while (	/* we have not yet obtained our array */
+	        !last_index
+	&&	/* and there is still a (prime) size left to try */
+	        n >= 0
+	) {
+		last_index_table_size = prime[n];
 		last_index = (size_t *)
-			TryCalloc(hash_table_size, sizeof (size_t));
+			TryCalloc(last_index_table_size, sizeof (size_t));
 		n--;
 	}
 	if (!last_index) {
 		fatal("out of memory");
 	}
 
-	/* find sample positions */
+	/* find sample positions
+	   (if Min_Run_Size < N_SAMPLES there will be duplicates)
+	*/
 	for (n = 0; n < N_SAMPLES; n++) {
-		/* straigh-line approximation; uninituitive as usual */
+		/* straight-line approximation; uninituitive as usual */
 		sample_pos[n] = (
 			(2 * n * (Min_Run_Size - 1) + (N_SAMPLES - 1))
 		/	(2 * (N_SAMPLES - 1))
@@ -206,18 +207,21 @@ make_forward_references_hash1(void) {
 
 	init_hash_table();
 
-	/* set up the forward references using the last_index hash table */
-	for (n = 0; n < Number_Of_Texts; n++) {
+	/* set up the forward references using the last_index[] hash table */
+	for (n = 0; n < Number_of_Texts; n++) {
 		struct text *txt = &Text[n];
 		size_t j;
 
-		for (	/* all pos'ns in txt except the last Min_Run_Size-1 */
+		for (	/* all positions in txt ... */
 			j = txt->tx_start;			/* >= 1 */
+			/* ... except the last Min_Run_Size-1 */
 			j + Min_Run_Size - 1 < txt->tx_limit;
 			j++
 		) {
 			if (May_Be_Start_Of_Run(Token_Array[j])) {
-				size_t h = hash1(&Token_Array[j]);
+				/* the hash value is used here for an index */
+				size_t h = hash1(&Token_Array[j])
+					% last_index_table_size;
 
 				if (last_index[h]) {
 					forward_reference[last_index[h]] = j;
@@ -229,55 +233,78 @@ make_forward_references_hash1(void) {
 	Free((char *)last_index);
 
 #ifdef	DB_FORW_REF
-	db_forward_references("first hashing");
+	db_forward_reference_check("first hashing");
 #endif	/* DB_FORW_REF */
 }
 
 static size_t
 hash1(const Token *p) {
-	/*	hash1(p) returns the hash code of Min_Run_Size
+	/*	The function hash1(p) returns a hash code of the Min_Run_Size
 		tokens starting at p; caller guarantees that there
 		are at least Min_Run_Size tokens.
+		Since its value is used as an index in a hash array, it needs
+		to be as smooth as possible.
+		Its type is size_t.
 	*/
-	uint64_t h_val;
+
+	/* The hash type and its width */
+#if	0
+#define	HASH_T	uint64_t
+#define	HASH_W	64
+#else
+#define	HASH_T	uint32_t		/* Turns out to be at least as good */
+#define	HASH_W	32
+#endif
+	HASH_T h_val;
 	int n;
 
+	/* The hash operation */
+#if	1
+#define	OPERATION	^
+#elif	0
+#define	OPERATION	+		/* does not seem to make any diff. */
+#else
+#define	OPERATION	+ 613 *		/* does not seem to make any diff. */
+#endif
+
 	h_val = 0;
 	for (n = 0; n < N_SAMPLES; n++) {
-		h_val = (h_val << 2) OPERATION Token2int(p[sample_pos[n]]);
-		if (h_val & (1ULL<<63)) {
-			h_val ^= (1ULL<<63|1);
+		/* left-most bit of h_val is 0 */
+		/* do a circular left shift over the HASH_W-1 right-most bits */
+		h_val <<= 1;
+		if (	/* left-most bit of h_val is now 1 */
+			h_val & (((HASH_T)1)<<(HASH_W-1))
+		) {	/* move it to the end */
+			h_val ^= (((HASH_T)1)<<(HASH_W-1)|1);
 		}
+		/* left-most bit of h_val is again 0 */
+		/* update */
+		h_val = h_val OPERATION Token2int(p[sample_pos[n]]);
+		/* left-most bit of h_val is still 0 */
 	}
 
 #ifdef	DB_HASH
-	/* reduce h_val to the type yielded by hash1(), and print the
-	   result in a responsible way
-	*/
-	size_t h = (size_t) (h_val % hash_table_size);
-	fprintf(Debug_File, "hash1 = %s\n", any_uint2string(h, 0));
+	size_t h = (size_t)h_val;
+	fprintf(Debug_File, "h_val = %s\n", any_uint2string(h, 0));
 #endif	/* DB_HASH */
 
-	return (size_t) (h_val % hash_table_size);
+	return (size_t)h_val;
 }
 
-static size_t hash2(const Token *);
+static vlong_uint hash2(const Token *);
 
 static void
-make_forward_references_hash2(void) {
+clean_forward_references_hash2(void) {
 	size_t i;
 
-	/*	Clean out spurious matches, by a quadratic algorithm.
-		Note that we do not want to eliminate overlapping
-		sequences in this stage, since we might be removing the
-		wrong copy.
-	*/
-	for (i = 0; i+Min_Run_Size < Text_Length(); i++) {
+	/* Clean out spurious matches, by a slightly quadratic algorithm. */
+	for (i = 0; i+Min_Run_Size < Token_Array_Length(); i++) {
 		size_t j = i;
-		size_t h2 = hash2(&Token_Array[i]);
+		vlong_uint h2 = hash2(&Token_Array[i]);
+		/* The hash value h2 is used as a representative.*/
 
-		/*	Find the first token sequence in the chain
-			with same secondary hash code.
+		/* Find the first token sequence in the chain with the same
+		   secondary hash code ...
 		*/
 		while (	/* there is still a forward reference */
 			(j = forward_reference[j])
@@ -286,54 +313,52 @@ make_forward_references_hash2(void) {
 		) {
 			/* continue searching */
 		}
-		/* short-circuit forward reference to it, or to zero */
+		/* ... and short-circuit forward reference to it, or to zero. */
 		forward_reference[i] = j;
 	}
 
 #ifdef	DB_FORW_REF
-	db_forward_references("second hashing");
+	db_forward_reference_check("second hashing");
 #endif	/* DB_FORW_REF */
 }
 
-static size_t
+static vlong_uint
 hash2(const Token *p) {
-	/*	A simple-minded hashing for the secondary sweep;
-		sample first, middle, and last token, and on 64-bit systems
-		also two tokens from in between these.
+	/*	The function hash2(p) returns a representative code for the
+		Min_Run_Size tokens starting at p; caller guarantees that there
+		are at least Min_Run_Size tokens.
+		Since its value is used as a representative in a comparison,
+		it needs to be as unique as possible.
+		Its type is vlong_uint.
 	*/
 	int pos_last_sample = N_SAMPLES - 1;
-	uint64_t h_val = 0;
-	h_val ^= ((uint64_t)Token2int(p[sample_pos[0]])) << 0;
-	h_val ^= ((uint64_t)Token2int(p[sample_pos[pos_last_sample]])) << 16;
-	h_val ^= ((uint64_t)Token2int(p[sample_pos[pos_last_sample/2]])) << 24;
-	h_val ^= ((uint64_t)Token2int(p[sample_pos[pos_last_sample*1/4]]))<<32;
-	h_val ^= ((uint64_t)Token2int(p[sample_pos[pos_last_sample*3/4]]))<<48;
-	/* the last two are ignored on a 32-bit system */
-	h_val *= 2147483647;
-	h_val &= 017777777777;
+	vlong_uint h_val = 0;
+	/* macro for readability (not relying on C compiler to do in-lining) */
+#define	extract_Token(pos)	((vlong_uint)Token2int(p[sample_pos[pos]]))
+#define	VLONG_W			((sizeof (vlong_uint))*8)
+	h_val ^= extract_Token(0) << 0;
+	h_val ^= extract_Token(pos_last_sample)     << (VLONG_W*1/5);
+	h_val ^= extract_Token(pos_last_sample/2)   << (VLONG_W*2/5);
+	h_val ^= extract_Token(pos_last_sample*1/4) << (VLONG_W*3/5);
+	h_val ^= extract_Token(pos_last_sample*3/4) << (VLONG_W*4/5);
 
 #ifdef	DB_HASH
-	/* reduce h_val to the type yielded by hash2(), and print the
-	   result in a responsible way
-	*/
-	size_t h = (size_t)h_val;
-	fprintf(Debug_File, "hash2 = %s\n", any_uint2string(h, 0));
+	/* print the result */
+	fprintf(Debug_File, "hash2 = %s\n", any_uint2string(h_val, 0));
 #endif	/* DB_HASH */
 
-	return (size_t)h_val;
+	return h_val;
 }
 
 #ifdef	DB_FORW_REF
 
-static int hash3(const Token *, const Token *);
-
 static void
 db_print_forward_references(void) {
 	size_t n;
 	size_t *printed_at =
-		(size_t *)Calloc(Text_Length(), sizeof (size_t));
+		(size_t *)Calloc(Token_Array_Length(), sizeof (size_t));
 
-	for (n = 1; n < Text_Length(); n++) {
+	for (n = 1; n < Token_Array_Length(); n++) {
 		size_t fw = forward_reference[n];
 		if (fw == 0) continue;
 		fprintf(Debug_File, "FWR[%s]:", any_uint2string(n, 0));
@@ -354,32 +379,8 @@ db_print_forward_references(void) {
 	Free((void *)printed_at);
 }
 
-static void
-make_forward_references_hash3(void) {
-	size_t i;
-
-	/* Do a third hash to check up on the previous two */
-
-	/* This time we use a genuine compare */
-	for (i = 0; i+Min_Run_Size < Text_Length(); i++) {
-		size_t j = i;
-
-		while (	/* there is still a forward reference */
-			(j = forward_reference[j])
-		&&	/* its hash code does not match */
-			!hash3(&Token_Array[i], &Token_Array[j])
-		) {
-			/* continue searching */
-		}
-		/* short-circuit forward reference to it, or to zero */
-		forward_reference[i] = j;
-	}
-
-	db_forward_references("third hashing");
-}
-
 static int
-hash3(const Token *p, const Token *q) {
+is_eq_min_run(const Token *p, const Token *q) {
 	/* a full comparison for the tertiary sweep */
 	size_t n;
 
@@ -389,6 +390,32 @@ hash3(const Token *p, const Token *q) {
 	return 1;
 }
 
+static void
+db_make_forward_references_perfect(void) {
+	size_t i;
+
+	/* Simulate a perfect hash by doing a full comparison
+	   over Min_Run_Size, for gathering statistics.
+	*/
+
+	for (i = 0; i+Min_Run_Size < Token_Array_Length(); i++) {
+		size_t j = i;
+
+		while (	/* there is still a forward reference */
+			(j = forward_reference[j])
+		&&	/* it does not match over Min_Run_Size */
+			!is_eq_min_run(&Token_Array[i], &Token_Array[j])
+		) {
+			/* continue searching */
+		}
+		/* short-circuit forward reference to it, or to zero */
+		forward_reference[i] = j;
+	}
+	/* now we have perfect forward references */
+
+	db_forward_reference_check("full Min_Run_Size comparison");
+}
+
 static size_t
 db_frw_chain(size_t n, char *crossed_out) {
 	if (forward_reference[n] == 0) {
@@ -410,27 +437,17 @@ db_frw_chain(size_t n, char *crossed_out) {
 		n_entries++;
 		crossed_out[fw] = 1;
 	}
+#ifdef	DB_FORW_REF_PRINT
 	fprintf(Debug_File, "chain_start = %s, n_entries = %s\n",
 		any_uint2string(n, 0), any_uint2string(n_entries, 0));
+#endif	/* DB_FORW_REF_PRINT */
 
 	/* return chain length */
 	return n_entries - 1;
 }
 
 static void
-db_forward_references(const char *msg) {
-	size_t n;
-	size_t n_frw_chains = 0;	/* number of forward ref. chains */
-	size_t tot_frwc_len = 0;
-	char *crossed_out;
-
-	fprintf(Debug_File, "\n\n**** DB_FORWARD_REFERENCES, %s ****\n", msg);
-	fprintf(Debug_File, "hash_table_size = %s\n",
-		any_uint2string(hash_table_size, 0));
-	fprintf(Debug_File, "N_SAMPLES = %d\n", N_SAMPLES);
-
-	crossed_out = (char *)Calloc(Text_Length(), sizeof (char));
-
+db_forward_reference_check(const char *msg) {
 	/*	Each forward_reference[n] starts in principle a new
 		chain, and these chains never touch each other.
 		We check this property by marking the positions in each
@@ -439,25 +456,37 @@ db_forward_references(const char *msg) {
 		and we have an error.
 		We also determine the lengths of the chains, for statistics.
 	*/
+	size_t n;
+	size_t n_frw_chains = 0;	/* number of forward ref. chains */
+	size_t tot_frwc_len = 0;
+	char *crossed_out = (char *)Calloc(Token_Array_Length(), sizeof (char));
+
+	fprintf(Debug_File, "\n\n**** DB_FORWARD_REFERENCES, %s ****\n", msg);
+	fprintf(Debug_File, "last_index_table_size = %s\n",
+		any_uint2string(last_index_table_size, 0));
+	fprintf(Debug_File, "N_SAMPLES = %d\n", N_SAMPLES);
+
 	if (forward_reference[0]) {
 		fprintf(Debug_File,
 			">>>> forward_reference[0] is not zero <<<<\n"
 		);
 	}
-	for (n = 1; n < Text_Length(); n++) {
+	for (n = 1; n < Token_Array_Length(); n++) {
 		if (forward_reference[n] && !crossed_out[n]) {
 			/* start of a new chain */
 			n_frw_chains++;
 			tot_frwc_len += db_frw_chain(n, crossed_out);
 		}
 	}
+#ifdef	DB_FORW_REF_PRINT
 	db_print_forward_references();
+#endif	/* DB_FORW_REF_PRINT */
 
-	Free((char *)crossed_out);
+	Free((void *)crossed_out);
 
 	fprintf(Debug_File,
 		"text length = %s, # forward chains = %s, total frw chain length = %s\n\n",
-		any_uint2string(Text_Length(), 0),
+		any_uint2string(Token_Array_Length(), 0),
 		any_uint2string(n_frw_chains, 0),
 		any_uint2string(tot_frwc_len, 0)
 	);
