@@ -1,6 +1,6 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: idf.c,v 2.17 2013-04-28 16:30:40 Gebruiker Exp $
+	$Id: idf.c,v 2.19 2015-01-17 10:20:40 dick Exp $
 */
 
 #include	<string.h>
@@ -45,6 +45,7 @@ idf_hashed(const char *str) {
 	while (*str) {
 		int ch = *str++ & 0377;
 
+		/* ignore spaces in spaced words */
 		if (ch == ' ') continue;
 
 		/* -1 <= h <= 2^31-1 */
@@ -73,3 +74,14 @@ idf_hashed(const char *str) {
 	return int2Token(h);
 	/* this avoids the regular tokens and End_Of_Line */
 }
+
+void
+lower_case(char *str) {
+	char *s;
+
+	for (s = str; *s; s++) {
+		if ('A' <= *s && *s <= 'Z') {
+			*s += (-'A' + 'a');
+		}
+	}
+}
