@@ -1,6 +1,6 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: pass2.c,v 2.21 2013-04-28 16:30:42 Gebruiker Exp $
+	$Id: pass2.c,v 2.23 2015-01-12 09:16:13 dick Exp $
 */
 
 #include	<stdio.h>
@@ -12,20 +12,18 @@
 #include	"lang.h"
 #include	"pass2.h"
 
-#undef	DB_POS
 #ifdef	DB_POS
 static void db_print_pos_list(const char *, const struct text *);
 static void db_print_lex(const char *);
 #endif
 
 static void pass2_txt(struct text *txt);
-static int next_eol_obtained(void);
 
 void
 Retrieve_Runs(void) {
 	int n;
 
-	for (n = 0; n < Number_Of_Texts; n++) {
+	for (n = 0; n < Number_of_Texts; n++) {
 		pass2_txt(&Text[n]);
 	}
 }
@@ -47,7 +45,7 @@ pass2_txt(struct text *txt) {
 		return;
 
 	/* Open_Text() initializes lex_nl_cnt and lex_tk_cnt */
-	if (!Open_Text(Second, txt)) {
+	if (!Open_Text(Second_Pass, txt)) {
 		fprintf(stderr, ">>>> File %s disappeared <<<<\n",
 			txt->tx_fname
 		);
@@ -82,17 +80,22 @@ pass2_txt(struct text *txt) {
 		/* we scan the pos list and the file in parallel */
 
 		/* find the corresponding line */
-		while (pos->ps_tk_cnt >= lex_tk_cnt) {	/* was >= ZZ */
+		while (pos->ps_tk_cnt >= lex_tk_cnt) {
 			/* pos does not refer to this line, try the next */
 
 			/* shift the administration */
 			old_nl_cnt = lex_nl_cnt;
 			/* and get the next eol position */
-			if (!next_eol_obtained()) {
-				/* ouch! not enough lines! */
-				fprintf(stderr, ">>>> File %s modified <<<<\n",
-					txt->tx_fname
-				);
+			if (!Next_Text_EOL_Obtained()) {
+				/* reached end of file without obtaining EOL */
+				if (!txt->tx_EOL_terminated) {
+					/* that's OK then */
+				} else {
+					fprintf(stderr,
+						">>>> File %s modified <<<<\n",
+						txt->tx_fname
+					);
+				}
 				break;
 			}
 #ifdef	DB_POS
@@ -118,17 +121,9 @@ pass2_txt(struct text *txt) {
 #endif	/* DB_POS */
 
 	/* Flush the flex buffers; it's easier than using YY_BUFFER_STATE. */
-	while (Next_Text_Token_Obtained(Second));
+	while (Next_Text_EOL_Obtained());
 
-	Close_Text(Second, txt);
-}
-
-static int
-next_eol_obtained(void) {
-	while (Next_Text_Token_Obtained(Second)) {
-		if (Token_EQ(lex_token, End_Of_Line)) return 1;
-	}
-	return 0;
+	Close_Text(Second_Pass, txt);
 }
 
 #ifdef	DB_POS
