@@ -1,6 +1,6 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: runs.c,v 1.7 2014-01-26 21:52:59 Gebruiker Exp $
+	$Id: runs.c,v 1.8 2015-01-14 16:47:27 dick Exp $
 */
 
 #include	"sim.h"
@@ -18,6 +18,7 @@ void
 add_to_runs(struct run *r) {
 	if (InsertAiso(r)) return;
 
+	/* insert failed */
 	if (!aiso_overflow) {
 		fprintf(stderr, ">>>> Memory overflow: too many runs found\n");
 		aiso_overflow = 1;
@@ -34,7 +35,7 @@ db_run_info(const char *msg, const struct run *run, int lines_too) {
 	if (msg) {
 		fprintf(Debug_File, "%s: ", msg);
 	}
-	fprintf(Debug_File, "File %s / file %s:\n",
+	fprintf(Debug_File, "\"%s\" / \"%s\":\n",
 		cnk0->ch_text->tx_fname, cnk1->ch_text->tx_fname
 	);
 	fprintf(Debug_File, "from %s %s/%s to %s/%s:", token_name,
