@@ -1,6 +1,6 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: stream.c,v 2.12 2014-01-26 21:52:59 Gebruiker Exp $
+	$Id: stream.c,v 2.13 2015-01-22 14:38:28 dick Exp $
 */
 
 #include	<stdio.h>
@@ -65,28 +65,27 @@ Print_Stream(const char *fname) {
 		return;
 	}
 
-	if (!is_set_option('T')) {
-		fprintf(Output_File,
-			" showing token stream:\nnl_cnt, tk_cnt: %ss",
-			token_name
-		);
+	fprintf(Output_File, " showing the %s stream\n", token_name);
 
-		lex_token = End_Of_Line;
-		do {
-			if (Token_EQ(lex_token, End_Of_Line)) {
-				fprintf(Output_File, "\n%s,%s:",
-					size_t2string(lex_nl_cnt),
-					size_t2string(lex_tk_cnt)
-				);
-			}
-			else {
-				fprintf(Output_File, " ");
-				fprint_token(Output_File, lex_token);
-			}
-		} while (Next_Stream_Token_Obtained());
+	lex_token = End_Of_Line;
+	do {
+		if (Token_EQ(lex_token, End_Of_Line)) {
+			fprintf(Output_File,
+				"line # = %s, %s # = %s:\n",
+				size_t2string(lex_nl_cnt),
+				token_name,
+				size_t2string(lex_tk_cnt)
+			);
+		}
+		else {
+			extern char *yytext;
+			fprintf(Output_File, " %s -> ", yytext);
+			fprint_token(Output_File, lex_token);
+			fprintf(Output_File, "\n");
+		}
+	} while (Next_Stream_Token_Obtained());
 
-		fprintf(Output_File, "\n");
-	}
+	fprintf(Output_File, "\n");
 
 	Close_Stream();
 }
