@@ -1,6 +1,6 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: text.h,v 1.5 2013-04-28 16:30:43 Gebruiker Exp $
+	$Id: text.h,v 1.7 2015-01-12 09:16:13 dick Exp $
 */
 
 /*	Implements the access to the lexical scanner.
@@ -9,16 +9,21 @@
 	information only.
 */
 
+/* The input files are called "texts" */
+
 struct text {
 	const char *tx_fname;	/* the file name */
+	size_t tx_start;	/* index of first token in Token_Array[]
+				   belonging to the text */
+	size_t tx_limit;	/* index of first position in Token_Array[]
+				   not belonging to the text */
+	size_t tx_nl_start;	/* possibly newline pointer for pass2 */
+	size_t tx_nl_limit;
+	int tx_EOL_terminated;	/* Boolean */
 	struct position *tx_pos;/* list of positions in this file that are
 				   part of a chunk; sorted and updated by
 				   Pass 2
 				*/
-	size_t tx_start;	/* positions in Token_Array[] for the text */
-	size_t tx_limit;
-	size_t tx_nl_start;	/* possibly newline pointer for pass2 */
-	size_t tx_nl_limit;
 };
 
 struct position {
@@ -33,13 +38,14 @@ struct position {
 };
 
 extern struct text *Text;		/* Text[], one for each input file */
-extern int Number_Of_Texts;		/* number of text files */
-extern int Number_Of_New_Texts;		/* number of new text files */
+extern int Number_of_Texts;		/* number of text files */
+extern int Number_of_New_Texts;		/* number of new text files */
 
 extern void Init_Text(int nfiles);
-enum Pass {First, Second};
+enum Pass {First_Pass, Second_Pass};
 extern int Open_Text(enum Pass pass, struct text *txt);
-extern int Next_Text_Token_Obtained(enum Pass pass);
+extern int Next_Text_Token_Obtained(void);
+extern int Next_Text_EOL_Obtained(void);
 extern void Close_Text(enum Pass pass, struct text *txt);
 
 #ifdef	DB_NL_BUFF
