@@ -1,8 +1,11 @@
 /*	This file is part of the software similarity tester SIM.
 	Written by Dick Grune, Vrije Universiteit, Amsterdam.
-	$Id: tokenarray.c,v 1.15 2013-04-30 20:12:39 Gebruiker Exp $
+	$Id: tokenarray.c,v 1.16 2015-01-12 09:16:13 dick Exp $
 */
 
+#include	<stdio.h>
+#include	<stdlib.h>
+
 #include	"error.h"
 #include	"Malloc.h"
 #include	"token.h"
@@ -48,6 +51,6 @@ Store_Token(Token tk) {
 }
 
 size_t
-Text_Length(void) {
+Token_Array_Length(void) {
 	return tk_free;
 }
